@@ -1,3 +1,7 @@
+test_that("ping", {
+  expect_type(ping_ollama(), "logical")
+})
+
 test_that("verbose", {
   expect_no_message({
     skip_if_not(ping_ollama(silent = TRUE))
